@@ -21,7 +21,8 @@ use Data::Dumper;
 use SQL::Translator::Parser::DB2;
 use SQL::Translator::Schema::Constants;
 
-use vars qw[ $DEBUG @EXPORT_OK ];
+use vars qw[ $DEBUG $VERSION @EXPORT_OK ];
+$VERSION = '1.60';
 $DEBUG   = 0 unless defined $DEBUG;
 
 # -------------------------------------------------------------------
