@@ -1,7 +1,5 @@
 package SQL::Translator::Parser::DBI::MySQL;
 
-# -------------------------------------------------------------------
-# $Id: MySQL.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -42,7 +40,8 @@ use Data::Dumper;
 use SQL::Translator::Schema::Constants;
 use SQL::Translator::Parser::MySQL;
 
-use vars qw[ $DEBUG @EXPORT_OK ];
+use vars qw[ $DEBUG $VERSION @EXPORT_OK ];
+$VERSION = '1.60';
 $DEBUG   = 0 unless defined $DEBUG;
 
 # -------------------------------------------------------------------
@@ -50,7 +49,9 @@ sub parse {
     my ( $tr, $dbh ) = @_;
     my $schema       = $tr->schema;
     my @table_names  = @{ $dbh->selectcol_arrayref('show tables') };
-    my @skip_tables = defined $tr->parser_args->{skip}?split(/,/, $tr->parser_args->{skip}):();
+    my @skip_tables  = defined $tr->parser_args->{skip}
+                       ? split(/,/, $tr->parser_args->{skip})
+                       : ();
 
     $dbh->{'FetchHashKeyName'} = 'NAME_lc';
 
