@@ -1,7 +1,5 @@
 package SQL::Translator::Parser::xSV;
 
-# -------------------------------------------------------------------
-# $Id: xSV.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -66,7 +64,8 @@ C<SQL::Translator::Utils::normalize_name>.
 # -------------------------------------------------------------------
 
 use strict;
-use vars qw(@EXPORT);
+use vars qw($VERSION @EXPORT);
+$VERSION = '1.60';
 
 use Exporter;
 use Text::ParseWords qw(quotewords);
@@ -190,7 +189,7 @@ sub parse {
 =head1 AUTHORS
 
 Darren Chamberlain E<lt>darren@cpan.orgE<gt>,
-Ken Y. Clark E<lt>kclark@cpan.orgE<gt>.
+Ken Youens-Clark E<lt>kclark@cpan.orgE<gt>.
 
 =head1 SEE ALSO
 
