@@ -1,7 +1,5 @@
 package SQL::Translator::Producer::Diagram;
 
-# -------------------------------------------------------------------
-# $Id: Diagram.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -41,7 +39,8 @@ use Data::Dumper;
 use SQL::Translator::Schema::Constants;
 use SQL::Translator::Utils qw(debug);
 
-use vars qw[ $DEBUG ];
+use vars qw[ $VERSION $DEBUG ];
+$VERSION = '1.60';
 $DEBUG   = 0 unless defined $DEBUG;
 
 use constant VALID_FONT_SIZE => {
@@ -506,7 +505,7 @@ sub produce {
     #
     debug("imap file = '$imap_file'");
     if ( $imap_file && @imap_coords ) {
-        open my $fh, ">$imap_file" or die "Can't write '$imap_file': $!\n";
+        open my $fh, '>', $imap_file or die "Can't write '$imap_file': $!\n";
         print $fh qq[<html><body><img src="" usemap="#imap" border="0">\n].
             qq[<map name="imap">\n];
         for my $rec ( @imap_coords ) {
@@ -521,7 +520,8 @@ sub produce {
     # Print the image.
     #
     if ( $out_file ) {
-        open my $fh, ">$out_file" or die "Can't write '$out_file': $!\n";
+        open my $fh, '>', $out_file or die "Can't write '$out_file': $!\n";
+        binmode $fh;
         print $fh $gd->$output_type;
         close $fh;
     }
@@ -538,6 +538,6 @@ sub produce {
 
 =head1 AUTHOR
 
-Ken Y. Clark E<lt>kclark@cpan.orgE<gt>.
+Ken Youens-Clark E<lt>kclark@cpan.orgE<gt>.
 
 =cut
