@@ -233,7 +233,7 @@ use SQL::Translator::Utils qw(debug);
 use Scalar::Util qw/openhandle/;
 
 use vars qw[ $VERSION $DEBUG ];
-$VERSION = '1.59';
+$VERSION = '1.60';
 $DEBUG   = 0 unless defined $DEBUG;
 
 sub produce {
@@ -519,7 +519,7 @@ sub produce {
           $node_args->{cluster} = $cluster_name;
         }
 
-        $gv->add_node ($table_name, %$node_args);
+        $gv->add_node(qq["$table_name"], %$node_args);
 
         debug("Processing table '$table_name'");
 
@@ -631,12 +631,11 @@ sub produce {
 
 =head1 AUTHOR
 
-Ken Youens-Clark E<lt>kclark@cpan.orgE<gt>
-
-Jonathan Yu E<lt>frequency@cpan.orgE<gt>
+Ken Youens-Clark E<lt>kclark@cpan.orgE<gt>,
+Jonathan Yu E<lt>frequency@cpan.orgE<gt>.
 
 =head1 SEE ALSO
 
-SQL::Translator, GraphViz
+SQL::Translator, GraphViz.
 
 =cut
