@@ -98,7 +98,7 @@ context the slash will be still there to ensure compatibility with SQLPlus.
 
 use strict;
 use vars qw[ $VERSION $DEBUG $WARN ];
-$VERSION = '1.59';
+$VERSION = '1.60';
 $DEBUG   = 0 unless defined $DEBUG;
 
 use SQL::Translator::Schema::Constants;
@@ -822,7 +822,7 @@ script.
 
 =head1 AUTHOR
 
-Ken Y. Clark E<lt>kclark@cpan.orgE<gt>.
+Ken Youens-Clark E<lt>kclark@cpan.orgE<gt>.
 
 =head1 SEE ALSO
 
