@@ -1,7 +1,5 @@
 package SQL::Translator::Producer::Storable;
 
-# -------------------------------------------------------------------
-# $Id: Storable.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -41,8 +39,9 @@ takes a long time.
 =cut
 
 use strict;
-use vars qw($DEBUG @EXPORT_OK);
+use vars qw($DEBUG $VERSION @EXPORT_OK);
 $DEBUG = 0 unless defined $DEBUG;
+$VERSION = '1.60';
 
 use Storable;
 use Exporter;
