@@ -1,7 +1,5 @@
 package SQL::Translator::Producer::XML;
 
-# -------------------------------------------------------------------
-# $Id: XML.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # -------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -38,14 +36,15 @@ SQL::Translator::Producer::XML::SQLFairy.
 
 =head1 AUTHOR
 
-Ken Y. Clark E<lt>kclark@cpan.orgE<gt>.
+Ken Youens-Clark E<lt>kclark@cpan.orgE<gt>.
 
 =cut
 
 # -------------------------------------------------------------------
 
 use strict;
-use vars qw[ $DEBUG ];
+use vars qw[ $VERSION $DEBUG ];
+$VERSION = '1.60';
 $DEBUG = 1 unless defined $DEBUG;
 
 use SQL::Translator::Producer::XML::SQLFairy;
