@@ -1,7 +1,5 @@
 package SQL::Translator::Schema::Constants;
 
-# ----------------------------------------------------------------------
-# $Id: Constants.pm 1440 2009-01-17 16:31:57Z jawnsy $
 # ----------------------------------------------------------------------
 # Copyright (C) 2002-2009 SQLFairy Authors
 #
@@ -61,8 +59,9 @@ This module exports the following constants for Schema features;
 
 use strict;
 use base qw( Exporter );
-use vars qw( @EXPORT );
+use vars qw( @EXPORT $VERSION );
 require Exporter;
+$VERSION = '1.60';
 
 @EXPORT = qw[ 
     CHECK_C
@@ -105,6 +104,6 @@ use constant UNIQUE => 'UNIQUE';
 
 =head1 AUTHOR
 
-Ken Y. Clark E<lt>kclark@cpan.orgE<gt>.
+Ken Youens-Clark E<lt>kclark@cpan.orgE<gt>.
 
 =cut
