@@ -1,6 +1,8 @@
 package SQL::Translator::Schema::Graph::Port;
 
 use strict;
-use warnings;
+
+use vars qw[ $VERSION ];
+$VERSION = '1.60';
 
 1;
