@@ -41,8 +41,7 @@ use Class::MakeMethods::Utility::Ref qw( ref_compare );
 
 use vars qw[ $VERSION ];
 
-$VERSION = '1.59';
-
+$VERSION = '1.60';
 
 =head1 Construction
 
@@ -202,18 +201,11 @@ Determines if this object is the same as another.
 
 # ----------------------------------------------------------------------
 sub _compare_objects {
-	my $self = shift;
-	my $obj1 = shift;
-	my $obj2 = shift;
+	my $self   = shift;
+	my $obj1   = shift;
+	my $obj2   = shift;
 	my $result = (ref_compare($obj1, $obj2) == 0);
-#	if ( !$result ) {
-#		use Carp qw(cluck);
-#		cluck("How did I get here?");
-#		use Data::Dumper;
-#		$Data::Dumper::Maxdepth = 1;
-#		print "obj1: ", Dumper($obj1), "\n";
-#		print "obj2: ", Dumper($obj2), "\n";
-#	}
+
 	return $result;
 }
 
@@ -223,14 +215,9 @@ sub _compare_objects {
 
 =pod
 
-=head1 SEE ALSO
-
-=head1 TODO
-
-=head1 BUGS
-
 =head1 AUTHOR
 
-Ken Y. Clark E<lt>kclark@cpan.orgE<gt>, Mark Addison E<lt>mark.addison@itn.co.ukE<gt> 
+Ken Youens-Clark E<lt>kclark@cpan.orgE<gt>, 
+Mark Addison E<lt>mark.addison@itn.co.ukE<gt>.
 
 =cut
