@@ -52,7 +52,7 @@ use base 'SQL::Translator::Schema::Object';
 
 use vars qw($VERSION);
 
-$VERSION = '1.59';
+$VERSION = '1.60';
 
 # ----------------------------------------------------------------------
 
@@ -292,7 +292,7 @@ sub DESTROY {
 
 =head1 AUTHORS
 
-Ken Y. Clark E<lt>kclark@cshl.orgE<gt>,
+Ken Youens-Clark E<lt>kclark@cshl.orgE<gt>,
 Paul Harrington E<lt>Paul-Harrington@deshaw.comE<gt>.
 
 =cut
